@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.0';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.1';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -303,13 +303,13 @@ sub configure {
         #
         # Auto generation --- distribution files
         #
-        'ModuleBuild',                    # build a Build.PL that uses Module::Build to install the distribution
-        'MetaYAML',                       # generate META.yml (supports CPAN::Meta::Spec v1.4)
-        'MetaJSON',                       # generate META.json (supports CPAN::Meta::Spec v2.0 upwards)
-        'Manifest',                       # generate Manifest (list of all files)
-        'License',                        # generate LICENSE
-        'ReadmeAnyFromPod',               # generate README (with dist's name, version, abstract, license)
-        'CPANFile',                       # generate "cpanfile"
+        'ModuleBuildTiny',                # add Build.PL that will use Module::Build::Tiny to install the distribution
+        'Manifest',                       # add Manifest (list of all files)
+        'MetaYAML',                       # add META.yml (supports CPAN::Meta::Spec v1.4)
+        'MetaJSON',                       # add META.json (supports CPAN::Meta::Spec v2.0 upwards)
+        'CPANFile',                       # add "cpanfile"
+        'License',                        # add LICENSE
+        'ReadmeAnyFromPod',               # add README (with dist's name, version, abstract, license)
 
         #
         # Auto generation --- tests
@@ -370,7 +370,7 @@ __PACKAGE__->meta->make_immutable;
 {
     package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
     # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.3.0';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.3.1';
 use Moose;
     use namespace::autoclean;
 
@@ -411,7 +411,7 @@ use Moose;
 {
     package Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep;
     # ABSTRACT: register all needed plugins in a bundle as runtime requirements
-$Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep::VERSION = '3.3.0';
+$Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep::VERSION = '3.3.1';
 use Moose;
     use namespace::autoclean;
 
@@ -509,7 +509,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 3.3.0
+version 3.3.1
 
 =head1 SYNOPSIS
 
